Learn R Programming

climatol (version 3.1)

datcli: Monthly climatic data of a single station

Description

Monthly climatic data, for a single station, of average precipitation, average daily maximum and minimum temperatures, and daily minimum temperatures.

Usage

data(datcli)

Arguments

Format

A matrix of 4 lines (variables) and 12 columns (months) of data

See Also

diagwl

Examples

Run this code
# NOT RUN {
data(datcli) 
print(datcli) 
# }

Run the code above in your browser using DataLab