| outrename | R Documentation |
This function inserts a suffix to the output file names of homogen,
to prevent them from being overwritten by any further run.
outrename(varcli, anyi, anyf, suffix)
varcli |
Short name of the studied climatic variable, as in the data file name. |
anyi |
Initial year of the study period. |
anyf |
Final year of the study period. |
suffix |
Suffix to be inserted (or removed) in the output file names. |
The suffix is appended to the varcli after a hyphen. The purpose of
this function is to allow a new application of homogen to the same
data with different parameters without overwriting the previous results.
Note that the output files are copied with the new names rather than just being renamed.
homogen
## Set a temporal working directory, write input files and homogenize them:
wd <- tempdir()
wd0 <- setwd(wd)
data(climatol_data)
write.table(Temp.est,'Temp_1961-2005.est',row.names=FALSE,col.names=FALSE)
write(Temp.dat,'Temp_1961-2005.dat',ncolumns=12)
datsubset('Temp',1961,2005,1991) #subset data to shorten example run time
homogen('Temp',1991,2005) #obtain homogenization output files
## Now run the example:
outrename('Temp',1991,2005,'bak') #rename them to avoid being overwritten
## Return to user's working directory:
setwd(wd0)
## Input and output files can be found in directory:
print(wd)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.